# toolbag

[![Latest PyPI version](https://img.shields.io/pypi/v/toolbag.svg)](https://pypi.python.org/pypi/toolbag/)

[![PyPI license](https://img.shields.io/pypi/l/toolbag.svg)](https://pypi.python.org/pypi/toolbag/)

[![PyPI format](https://img.shields.io/pypi/format/toolbag.svg)](https://pypi.python.org/pypi/toolbag/)

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/toolbag.svg)](https://pypi.python.org/pypi/toolbag/)

[![PyPI status](https://img.shields.io/pypi/status/toolbag.svg)](https://pypi.python.org/pypi/toolbag/)

Python toolbag, like a toolbox, but more flexible!

## Usage

## Installation

## Compatibility

## Licence

## Authors

`toolbag` was written by [Nils Müller](mailto:shimst3r@gmail.com).
